@@ -303,6 +303,16 @@ static SMTP_SESSION *smtp_connect_sock(int sock, struct sockaddr * sa,
     }
     stream = vstream_fdopen(sock, O_RDWR);
 
+    /*
+     * Avoid poor performance when TCP MSS > VSTREAM_BUFSIZE.
+     */
+    if (sa->sa_family == AF_INET
+#ifdef AF_INET6
+	|| sa->sa_family == AF_INET6
+#endif
+	)
+	vstream_tweak_tcp(stream);
+
     /*
      * Bundle up what we have into a nice SMTP_SESSION object.
      */
@@ -380,7 +390,7 @@ static void smtp_cleanup_session(SMTP_STATE *state)
     if (THIS_SESSION_IS_EXPIRED)
 	smtp_quit(state);			/* also disables caching */
     if (THIS_SESSION_IS_CACHED
-	/* Redundant tests for safety... */
+    /* Redundant tests for safety... */
 	&& vstream_ferror(session->stream) == 0
 	&& vstream_feof(session->stream) == 0) {
 	smtp_save_session(state);
